@@ -706,3 +706,24 @@ set of useful URLs or preparing a list to send to a someone else."
                          (:hr ""))))
                 (:p "None chosen."))))
       (when delete (mapcar #'buffer-delete buffers)))))
+
+(export-always 'render-menu)
+(defun render-menu (mode-symbol &optional (buffer (current-buffer)))
+  "Render a menu for a given mode symbol."
+  (spinneret:with-html
+    (:div :class "mode-menu"
+          (loop for command in (nyxt::list-mode-commands mode-symbol)
+                collect
+                   (let ((name (string-downcase (closer-mop:generic-function-name command)))
+                         (bindings (keymaps:pretty-binding-keys
+                                    (name command)
+                                    (current-keymaps buffer)
+                                    :print-style (keymaps:name (keyscheme buffer)))))
+                     (:nbutton
+                       :class "button binding"
+                       :text (if bindings (first bindings) "⏎")
+                       `(nyxt::run-async ,command))
+                     (:nbutton
+                       :class "button command"
+                       :text name
+                       `(nyxt::run-async ,command)))))))
