@@ -265,10 +265,8 @@ When done, call `call-next-method' to finalize the startup."
 In particular, this should understand Punycode.")
 
 (define-ffi-generic ffi-buffer-cookie-policy (buffer)
-  "Return the cookie 'accept' policy, one of of`:always',
-`:never' or `:no-third-party'.
-
-Setf-able with the same aforementioned values."
+  "Return the cookie policy.
+Setf-able.  Valid values are determined by the `cookie-policy' type."
   (:setter-p t))
 
 (define-ffi-generic ffi-preferred-languages (buffer)
@@ -379,7 +377,7 @@ Return the text cut."
   (echo-warning "Redoing edits is not yet implemented for this renderer."))
 
 ;; TODO: Move to alists for arbitrary number of params?
-(defvar *context-menu-commands* (make-hash-table)
+(defvar *context-menu-commands* (make-hash-table :test #'equal)
   "A hash table from labels to context menu commands.
 Once a context menu appears, those commands will be added to it as actions with
 the labels they have as hash keys.")
