@@ -429,7 +429,7 @@ The `input' should be a valid Lisp code `read'-able in the `eval-package'.
        "J" 'move-cell-down)))
    (style (theme:themed-css (theme *browser*)
             `(*
-              :font-family "monospace,monospace")
+              :font-family ,theme:monospace-font-family)
             `(body
               :margin "0")
             `("#container"
@@ -439,6 +439,7 @@ The `input' should be a valid Lisp code `read'-able in the `eval-package'.
               :width "97vw"
               :margin "1em")
             `(.input-area
+              :border-radius "3px"
               :background-color ,theme:secondary
               :width "99%"
               :padding "0.5rem")
@@ -465,6 +466,8 @@ The `input' should be a valid Lisp code `read'-able in the `eval-package'.
               :position "absolute"
               :bottom "1em"
               :right "1em")
+            `(".controls button"
+              :height "2rem")
             `(.cell-actions
               :display none)
             `(":focus-within ~ .cell-actions,
