@@ -70,11 +70,30 @@ in `prompter:object-attributes').
 See `nyxt::attribute-widths'.")
      (style
       (theme:themed-css (theme *browser*)
+        `(:font-face :font-family "public sans" :font-style "normal" :font-weight "400" :src ,(format nil "url('nyxt-resource:~a')" "PublicSans-Regular.woff") "format('woff')")
+        `(:font-face :font-family "public sans" :font-style "italic" :font-weight "400" :src ,(format nil "url('nyxt-resource:~a')" "PublicSans-Italic.woff") "format('woff')")
+        `(:font-face :font-family "public sans" :font-style "normal" :font-weight "100" :src ,(format nil "url('nyxt-resource:~a')" "PublicSans-Thin.woff") "format('woff')")
+        `(:font-face :font-family "public sans" :font-style "italic" :font-weight "100" :src ,(format nil "url('nyxt-resource:~a')" "PublicSans-ThinItalic.woff") "format('woff')")
+        `(:font-face :font-family "public sans" :font-style "normal" :font-weight "200" :src ,(format nil "url('nyxt-resource:~a')" "PublicSans-ExtraLight.woff") "format('woff')")
+        `(:font-face :font-family "public sans" :font-style "italic" :font-weight "200" :src ,(format nil "url('nyxt-resource:~a')" "PublicSans-ExtraLightItalic.woff") "format('woff')")
+        `(:font-face :font-family "public sans" :font-style "normal" :font-weight "300" :src ,(format nil "url('nyxt-resource:~a')" "PublicSans-Light.woff") "format('woff')")
+        `(:font-face :font-family "public sans" :font-style "italic" :font-weight "300" :src ,(format nil "url('nyxt-resource:~a')" "PublicSans-LightItalic.woff") "format('woff')")
+        `(:font-face :font-family "public sans" :font-style "normal" :font-weight "500" :src ,(format nil "url('nyxt-resource:~a')" "PublicSans-Medium.woff") "format('woff')")
+        `(:font-face :font-family "public sans" :font-style "italic" :font-weight "500" :src ,(format nil "url('nyxt-resource:~a')" "PublicSans-MediumItalic.woff") "format('woff')")
+        `(:font-face :font-family "public sans" :font-style "normal" :font-weight "600" :src ,(format nil "url('nyxt-resource:~a')" "PublicSans-SemiBold.woff") "format('woff')")
+        `(:font-face :font-family "public sans" :font-style "italic" :font-weight "600" :src ,(format nil "url('nyxt-resource:~a')" "PublicSans-SemiBoldItalic.woff") "format('woff')")
+        `(:font-face :font-family "public sans" :font-style "normal" :font-weight "700" :src ,(format nil "url('nyxt-resource:~a')" "PublicSans-Bold.woff") "format('woff')")
+        `(:font-face :font-family "public sans" :font-style "italic" :font-weight "700" :src ,(format nil "url('nyxt-resource:~a')" "PublicSans-BoldItalic.woff") "format('woff')")
+        `(:font-face :font-family "public sans" :font-style "normal" :font-weight "800" :src ,(format nil "url('nyxt-resource:~a')" "PublicSans-ExtraBold.woff") "format('woff')")
+        `(:font-face :font-family "public sans" :font-style "italic" :font-weight "800" :src ,(format nil "url('nyxt-resource:~a')" "PublicSans-ExtraBoldItalic.woff") "format('woff')")
+        `(:font-face :font-family "public sans" :font-style "normal" :font-weight "900" :src ,(format nil "url('nyxt-resource:~a')" "PublicSans-Black.woff") "format('woff')")
+        `(:font-face :font-family "public sans" :font-style "italic" :font-weight "900" :src ,(format nil "url('nyxt-resource:~a')" "PublicSans-BlackItalic.woff") "format('woff')")
+        `(:font-face :font-family "dejavu sans mono" :src ,(format nil "url('nyxt-resource:~a')" "DejaVuSansMono.ttf") "format('ttf')")
         `(*
-          :font-family "monospace,monospace"
           :font-size "14px"
           :line-height "18px")
         `(body
+          :font-family ,theme:font-family
           :border-right "2px solid"
           :border-color ,theme:primary
           :overflow "hidden"
@@ -99,6 +118,7 @@ See `nyxt::attribute-widths'.")
           :margin-right "-10px"
           :line-height "28px")
         `("#prompt-extra"
+          :font-family ,theme:monospace-font-family
           :z-index "1"
           :min-width "12px"
           :padding-right 14px !important
@@ -141,9 +161,11 @@ See `nyxt::attribute-widths'.")
           :cursor "pointer"
           :color ,theme:action)
         `(".button:hover svg path"
-           :stroke ,theme:action-)
+          :stroke ,theme:action-)
         `((:and .button (:or :visited :active))
           :color ,theme:background)
+        `(input
+          :font-family ,theme:monospace-font-family)
         `("#input"
           :height "28px"
           :margin-top "0"
@@ -163,16 +185,25 @@ See `nyxt::attribute-widths'.")
           :margin-left "10px"
           :margin-top "15px")
         `(".source-name"
+          :padding-left "4px"
           :background-color ,theme:secondary
           :color ,theme:on-secondary
           :display "flex"
           :justify-content "space-between"
           :align-items "stretch"
-          :line-height "24px"
-          :border-radius "3px 0 0 0")
+          :border-radius "2px 0 0 0")
+        '(".source-name > div"
+          :line-height "22px")
         `(".source-name > div > button"
           :padding "5px 4px 5px 4px"
           :min-height "100%")
+        `("#next-source > svg, #previous-source > svg"
+          :margin-bottom "2px"
+          :height "5px")
+        '("#previous-source"
+          :padding 0)
+        '("#next-source"
+          :padding 0)
         `("#suggestions"
           :background-color ,theme:background
           :color ,theme:on-background
@@ -180,9 +211,9 @@ See `nyxt::attribute-widths'.")
           :overflow-x "hidden"
           :height "100%"
           :margin-right "3px")
+        `(".suggestion-and-mark-count"
+          :font-family ,theme:monospace-font-family)
         `(".source-content"
-          :background-color ,theme:background
-          :color ,theme:on-background
           :margin-left "16px"
           :width "100%"
           :table-layout "fixed"
@@ -191,6 +222,8 @@ See `nyxt::attribute-widths'.")
            :height "20px"
            :padding-left "4px"
            :overflow "auto")
+          ("tr:not(:first-child)"
+           :font-family ,theme:monospace-font-family)
           ("tr:hover"
            :background-color ,theme:action-
            :color ,theme:on-action
@@ -529,7 +562,7 @@ This does not redraw the whole prompt buffer, use `prompt-render' for that."
                  (:div
                   (:nbutton
                     :id "next-source"
-                    :text (:raw (gethash "down-arrow.svg" *static-data*))
+                    :text (:raw (gethash "down.svg" *static-data*))
                     :title (format nil "Next source (~a)"
                                    (binding-keys (sym:resolve-symbol :next-source
                                                                      :command)
@@ -538,7 +571,7 @@ This does not redraw the whole prompt buffer, use `prompt-render' for that."
                     '(funcall (sym:resolve-symbol :next-source :command)))
                   (:nbutton
                     :id "previous-source"
-                    :text (:raw (gethash "up-arrow.svg" *static-data*))
+                    :text (:raw (gethash "up.svg" *static-data*))
                     :title (format nil "Previous source (~a)"
                                    (binding-keys (sym:resolve-symbol :previous-source
                                                                      :command)
@@ -548,10 +581,11 @@ This does not redraw the whole prompt buffer, use `prompt-render' for that."
                   (prompter:name source)
                   (if (prompter:hide-suggestion-count-p source)
                       ""
-                      (suggestion-and-mark-count prompt-buffer
-                                                 (prompter:suggestions source)
-                                                 (prompter:marks source)
-                                                 :enable-marks-p (prompter:enable-marks-p source)))
+                      (:span :class "suggestion-and-mark-count"
+                             (suggestion-and-mark-count prompt-buffer
+                                                        (prompter:suggestions source)
+                                                        (prompter:marks source)
+                                                        :enable-marks-p (prompter:enable-marks-p source))))
                   (if (prompter:ready-p source) "" "(In progress...)"))
                  (:div
                   (:nbutton
