@@ -393,7 +393,8 @@ Example:
 (defun internal-url-p (url)
   "Whether the URL is the `internal-page' one."
   ;; FIXME: Too simple. Maybe check for command presence too?
-  (string= "nyxt" (quri:uri-scheme (url url))))
+  (or (string= "nyxt" (quri:uri-scheme (url url)))
+      (string= "editor" (quri:uri-scheme (url url)))))
 
 (-> query-params->arglist ((types:association-list string string)) (values list &optional))
 (defun query-params->arglist (params)
