@@ -128,7 +128,6 @@ The handlers take the window as argument."))
 
 (defmethod initialize-instance :after ((window window) &key (browser *browser*)
                                        &allow-other-keys)
-  "Initialize some required slots like ID and status-buffer."
   (setf (window (status-buffer window)) window)
   (when browser
     (setf (id window) (new-id))
@@ -172,7 +171,7 @@ The handlers take the window as argument."))
 (export-always 'window-make)
 (defun window-make (browser)
   "Create a new window in BROWSER."
-  (let* ((window (ffi-window-make browser)))
+  (let ((window (ffi-window-make browser)))
     (setf (gethash (id window) (windows browser)) window)
     (unless (slot-value browser 'last-active-window)
       (setf (slot-value browser 'last-active-window) window))
